<h1 align = "center">:rocket: DeepNN :facepunch:</h1>

[![Downloads](http://pepy.tech/badge/DeepNN)](http://pepy.tech/project/DeepNN)
[![Downloads](https://pepy.tech/badge/DeepNN/month)](https://pepy.tech/project/DeepNN/month)
[![Downloads](https://pepy.tech/badge/DeepNN/week)](https://pepy.tech/project/DeepNN/week)
[![PyPI release](https://img.shields.io/pypi/v/DeepNN.svg)](https://pypi.python.org/pypi/DeepNN)
[![PyPI version](https://img.shields.io/pypi/pyversions/DeepNN.svg)](https://pypi.python.org/pypi/DeepNN)
---

# Install
```sh
pip install deepnn
```